@@ -109,7 +109,7 @@ get_grid_data <- function(x, autowidths, wrapping) {
 }
 
 grid_data_add_cell_info <- function(grid_data, x) {
-  cell_data <- fortify_style(x, "cells")
+  cell_data <- fortify_cells_properties(x)
 
   # merge with grid_data to keep only active cells
   keycols <- c("part", "ft_row_id", "col_id")
@@ -194,7 +194,7 @@ grid_data_add_cell_info <- function(grid_data, x) {
 
 #' @importFrom grid unit
 grid_data_add_par_info <- function(grid_data, x) {
-  par_data <- fortify_style(x, "pars")
+  par_data <- fortify_paragraphs_properties(x)
 
   # merge with grid_data to keep only active cells
   keycols <- c("part", "ft_row_id", "col_id")
@@ -987,7 +987,7 @@ calc_grid_image <- function(img_data, width = NULL, height = NULL) {
     class(image) <- c("flextableRasterChunk", class(image))
   } else if (is.character(img_data)) {
     if (!file.exists(img_data)) {
-      warning("error reading image: file '", shQuote(img_data), "' cannot be found.")
+      warning(sprintf("file '%s' can not be found.", img_data))
     } else if (requireNamespace("magick", quietly = TRUE)) {
       tryCatch(
         {
@@ -1003,7 +1003,7 @@ calc_grid_image <- function(img_data, width = NULL, height = NULL) {
         }
       )
     } else {
-      warning("package 'magick' is required to read image files")
+      warning(sprintf("package 'magick' is required to read image files"))
     }
   }
   image
