@@ -126,18 +126,18 @@ img_to_latex <- function(img_data, width, height){
 
   str_raster <- mapply(function(img_raster, new_file, width, height ){
     if(inherits(img_raster, "raster")){
-      png(filename = new_file, units = "in", res = 300, bg = "transparent", width = width, height = height)
+      agg_png(filename = new_file, units = "in", res = 300, background = "transparent", width = width, height = height)
       op <- par(mar=rep(0, 4))
       plot(img_raster, interpolate = FALSE, asp=NA)
       par(op)
       dev.off()
     } else if(is.character(img_raster)){
       if(!file.exists(img_raster)){
-        stop("file ", shQuote(img_raster), " could not be read")
+        stop(sprintf("File '%s' could not be found.", img_raster))
       }
       file.copy(from = img_raster, to = new_file, overwrite = TRUE)
     } else  {
-      stop("unknown image format")
+      stop("`image_data` can only be a raster or a filename.")
     }
     sprintf("\\includegraphics[width=%sin, height=%sin]{%s}", width, height, new_file)
   }, img_data, new_files, width, height, SIMPLIFY = FALSE, USE.NAMES = FALSE)
